# Home Assistant Polymer [![Build Status](https://travis-ci.org/home-assistant/home-assistant-polymer.svg?branch=master)](https://travis-ci.org/home-assistant/home-assistant-polymer)

This is the repository for the official [Home Assistant](https://home-assistant.io) frontend. The frontend is built on top of the following technologies:

 * [Websockets](https://developer.mozilla.org/en-US/docs/Web/API/WebSockets_API)
 * [Polymer](https://www.polymer-project.org/)
 * [Rollup](http://rollupjs.org/) to package Home Assistant JS
 * [Bower](https://bower.io) for Polymer package management

[![Screenshot of the frontend](https://raw.githubusercontent.com/home-assistant/home-assistant-polymer/master/docs/screenshot.png)](https://home-assistant.io/demo/)

[View demo of the Polymer frontend](https://home-assistant.io/demo/)  
[More information about Home Assistant](https://home-assistant.io)  
[Frontend development instructions](https://home-assistant.io/developers/frontend/)

## License
Home Assistant is open-source and Apache 2 licensed. Feel free to browse the repository, learn and reuse parts in your own projects.
